@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: 2021 2017-2021 Contributors to the OpenSTF project <korte.termijn.prognoses@alliander.com>
 #
 # SPDX-License-Identifier: MPL-2.0
-
+from typing import Union, List
 from datetime import datetime, timedelta
 
 import pandas as pd
@@ -11,7 +11,12 @@ from openstef_dbc.data_interface import _DataInterface
 
 
 class Predictions:
-    def get_predicted_load(self, pj, start_time=None, end_time=None):
+    def get_predicted_load(
+        self,
+        pj: dict,
+        start_time: datetime = None,
+        end_time: datetime = None,
+    ) -> pd.Series:
         """Get historic load predictions for given pid.
 
         This functions ignores component predictions that result from energy splitting.
@@ -31,22 +36,26 @@ class Predictions:
         if end_time is None:
             end_time = datetime.utcnow() + timedelta(days=2)
 
+        bind_params = {
+            "pid": pj["id"],
+            "dstart": start_time.isoformat(),
+            "dend": end_time.isoformat(),
+        }
+
         query = """
             SELECT mean("forecast") as forecast, mean("stdev") as stdev
             FROM forecast_latest..prediction
             WHERE (
-                "pid" = '{}' AND
+                "pid" = pid=$pid AND
                 "type" != 'est_demand'
                 AND "type" != 'est_pv'
                 AND "type" != 'est_wind'
-            ) AND time >= '{}' AND time < '{}'
+            ) AND time >= dstart=$dstart AND time < dend=$dend
             GROUP BY time(15m)
-        """.format(
-            pj["id"], start_time, end_time
-        )
+        """
 
         # Query the database
-        result = _DataInterface.get_instance().exec_influx_query(query)
+        result = _DataInterface.get_instance().exec_influx_query(query, bind_params)
 
         # Return result
         if "prediction" in result:
@@ -56,12 +65,12 @@ class Predictions:
 
     def get_predicted_load_tahead(
         self,
-        pj,
-        start_time=None,
-        end_time=None,
-        t_ahead=None,
-        component=False,
-    ):
+        pj: dict,
+        start_time: datetime = None,
+        end_time: datetime = None,
+        t_ahead: Union[List[str], str] = None,
+        component: bool = False,
+    ) -> pd.DataFrame:
         """Get historic load predictions for given pid and t_ahead.
 
         This functions ignores component predictions that result from energy splitting.
@@ -87,31 +96,38 @@ class Predictions:
         # If no t_ahead are provided ask influx for all t_ahead available
         if t_ahead is None:
             if component:
+
+                bind_params = {
+                    "pid": str(pj["id"]),
+                    "dstart": str(start_time),
+                    "dend": str(end_time),
+                }
                 query = """
                     SELECT mean("forecast_solar") as forecast, mean("stdev") as stdev
                     FROM forecast_latest..prediction_tAheads
-                    WHERE ("pid" = '{}'
+                    WHERE ("pid" = $pid
                     AND type" != 'est_demand'
                     AND "type" != 'est_pv'
                     AND "type" != 'est_wind')
-                    AND time >= '{}' AND time < '{}'
+                    AND time >= $dstart AND time < $dend
                     GROUP BY time(15m), "tAhead"
-                """.format(
-                    pj["id"], start_time, end_time
-                )
+                """
             else:
+                bind_params = {
+                    "pid": str(pj["id"]),
+                    "dstart": str(start_time),
+                    "dend": str(end_time),
+                }
                 query = """
                     SELECT mean("forecast") as forecast, mean("stdev") as stdev
                     FROM forecast_latest..prediction_tAheads
-                    WHERE ("pid" = '{}'
+                    WHERE ("pid" = $pid
                     AND "type" != 'est_demand'
                     AND "type" != 'est_pv'
                     AND "type" != 'est_wind')
-                    AND time >= '{}' AND time < '{}'
+                    AND time >= $dstart AND time < $dend
                     GROUP BY time(15m), "tAhead"
-                """.format(
-                    pj["id"], start_time, end_time
-                )
+                """
 
         # For a selection of t_aheads a custom query is generated
         else:
@@ -138,22 +154,26 @@ class Predictions:
             t_aheads = t_aheads[0:-2]
 
             # Make query for a selection of t_aheads
+            bind_params = {
+                "pid": str(pj["id"]),
+                "taheads": t_aheads,
+                "dstart": str(start_time),
+                "dend": str(end_time),
+            }
             query = """
                 SELECT mean("forecast") as forecast, mean("stdev") as stdev
                 FROM forecast_latest..prediction_tAheads
-                WHERE ("pid" = '{}' 
+                WHERE ("pid" = $pid
                     AND "type" != 'est_demand'
                     AND "type" != 'est_pv'
                     AND "type" != 'est_wind'
-                    AND ({}))
-                    AND time >= '{}' AND time < '{}'
+                    AND (taheads=$taheads))
+                    AND time >= $dstart AND time < $dend
                 GROUP BY time(15m), "tAhead"
-            """.format(
-                pj["id"], t_aheads, start_time, end_time
-            )
+            """
 
         # Query the database
-        result = _DataInterface.get_instance().exec_influx_query(query)
+        result = _DataInterface.get_instance().exec_influx_query(query, bind_params)
 
         # Convert to pandas DataFrame with a column for each tAhead
         predicted_load = pd.DataFrame()
